@@ -31,10 +31,9 @@
 #include <gnutls/pkcs11.h>
 
 #include <gnutls_extensions.h>  /* for _gnutls_ext_init */
+#include <gnutls_cryptodev.h>
 #include <locks.h>
 #include <system.h>
-#include <accelerated/cryptodev.h>
-#include <accelerated/accelerated.h>
 
 #include "sockets.h"
 #include "gettext.h"
@@ -50,7 +49,6 @@ ASN1_TYPE _gnutls_pkix1_asn;
 ASN1_TYPE _gnutls_gnutls_asn;
 
 gnutls_log_func _gnutls_log_func;
-gnutls_audit_log_func _gnutls_audit_log_func;
 int _gnutls_log_level = 0;      /* default log level */
 
 /**
@@ -71,24 +69,6 @@ gnutls_global_set_log_function (gnutls_log_func log_func)
   _gnutls_log_func = log_func;
 }
 
-/**
- * gnutls_global_set_audit_log_function:
- * @log_func: it is the audit log function
- *
- * This is the function where you set the logging function gnutls is
- * going to use.  This is different from gnutls_global_set_log_function()
- * because it will report the session of the event if any. Note that
- * that session might be null if there is no corresponding TLS session.
- *
- * gnutls_audit_log_func is of the form,
- * void (*gnutls_audit_log_func)( gnutls_session_t, int level, const char*);
- **/
-void
-gnutls_global_set_audit_log_function (gnutls_audit_log_func log_func)
-{
-  _gnutls_audit_log_func = log_func;
-}
-
 /**
  * gnutls_global_set_time_function:
  * @time_func: it's the system time function
@@ -173,6 +153,7 @@ gnutls_global_set_mem_functions (gnutls_alloc_function alloc_func,
 
 static int _gnutls_init = 0;
 
+
 /**
  * gnutls_global_init:
  *
@@ -223,8 +204,6 @@ gnutls_global_init (void)
       return GNUTLS_E_CRYPTO_INIT_FAILED;
     }
 
-  _gnutls_register_accel_crypto();
-
   /* initialize ASN.1 parser
    * This should not deal with files in the final
    * version.
@@ -269,7 +248,9 @@ gnutls_global_init (void)
       goto out;
     }
 
+#ifdef ENABLE_PKCS11
   gnutls_pkcs11_init (GNUTLS_PKCS11_FLAG_AUTO, NULL);
+#endif
 
   _gnutls_cryptodev_init ();
 
@@ -298,7 +279,9 @@ gnutls_global_deinit (void)
       asn1_delete_structure (&_gnutls_pkix1_asn);
       _gnutls_crypto_deregister ();
       _gnutls_cryptodev_deinit ();
+#ifdef ENABLE_PKCS11
       gnutls_pkcs11_deinit ();
+#endif
     }
   _gnutls_init--;
 }
