@@ -30,24 +30,10 @@
 
 void _gnutls_session_cert_type_set (gnutls_session_t session,
                                     gnutls_certificate_type_t);
-
-inline static gnutls_ecc_curve_t _gnutls_session_ecc_curve_get(gnutls_session_t session)
-{
-  return session->security_parameters.ecc_curve;
-}
-
-int _gnutls_session_is_ecc (gnutls_session_t session);
-
-void
-_gnutls_session_ecc_curve_set (gnutls_session_t session,
-                               gnutls_ecc_curve_t c);
-
 void
 _gnutls_record_set_default_version (gnutls_session_t session,
                                     unsigned char major, unsigned char minor);
 
-int _gnutls_record_overhead_rt(gnutls_session_t session);
-
 #include <gnutls_auth.h>
 
 #define CHECK_AUTH(auth, ret) if (gnutls_auth_get_type(session) != auth) { \
@@ -85,4 +71,3 @@ int _gnutls_PRF (gnutls_session_t session,
                  int total_bytes, void *ret);
 
 #define DEFAULT_CERT_TYPE GNUTLS_CRT_X509
-
